@@ -1,5 +1,5 @@
 /*
- * Copyright © 2007 Gerd Kohlberger <lowfi@chello.at>
+ * Copyright © 2007-2008 Gerd Kohlberger <lowfi@chello.at>
  *
  * This file is part of Mousetweaks.
  *
@@ -20,14 +20,18 @@
 #ifndef __MT_CTW_H__
 #define __MT_CTW_H__
 
+#include "mt-main.h"
+
 G_BEGIN_DECLS
 
-gboolean mt_ctw_init		   (MTClosure *mt, gint x, gint y);
-void	 mt_ctw_set_click_type	   (gint ct);
-void	 mt_ctw_update_sensitivity (MTClosure *mt);
-void	 mt_ctw_update_visibility  (MTClosure *mt);
-void	 mt_ctw_update_style	   (gint style);
-
+gboolean    mt_ctw_init               (MTClosure *mt,
+				       gint       x,
+				       gint       y);
+GtkWidget * mt_ctw_get_window         (void);
+void        mt_ctw_set_clicktype      (guint      ct);
+void        mt_ctw_update_sensitivity (MTClosure *mt);
+void        mt_ctw_update_visibility  (MTClosure *mt);
+void        mt_ctw_update_style       (gint       style);
 
 G_END_DECLS
 
